@@ -22,11 +22,12 @@ from .actions import help_action
 from .exceptions import CommandDefinitionError, ParameterDefinitionError
 from .formatting.commands import CommandHelpFormatter
 from .parameters.base import ParamBase, Parameter, BaseOption, BasePositional
-from .parameters import SubCommand, PassThru, ActionFlag, ParamGroup, Action
+from .parameters import SubCommand, PassThru, ActionFlag, ParamGroup, Action, Option
 
 if TYPE_CHECKING:
     from .config import CommandConfig
-    from .core import CommandType
+    from .context import Context
+    from .typing import CommandType
 
 __all__ = ['CommandParameters']
 
@@ -110,7 +111,7 @@ class CommandParameters:
         groups = set()
 
         for attr, param in self.command.__dict__.items():
-            if attr.startswith('__') or not isinstance(param, ParamBase):
+            if attr.startswith('__') or not isinstance(param, ParamBase):  # Name mangled Parameters are still processed
                 continue
 
             name = param.name
@@ -184,10 +185,10 @@ class CommandParameters:
                     self.sub_command = param
                 else:
                     self.action = param
-                    if not param.choices:
+                    if not param.has_choices:
                         raise CommandDefinitionError(f'No choices were registered for {self.action}')
 
-            if param.nargs.variable and not param.choices:
+            if param.nargs.variable and not param.has_choices:
                 var_nargs_param = param
 
         self.positionals = params
@@ -372,6 +373,16 @@ class CommandParameters:
 
     # endregion
 
+    def try_env_params(self, ctx: Context) -> Iterator[Option]:
+        for param in self.options:
+            try:
+                param.env_var  # noqa
+            except AttributeError:
+                pass
+            else:
+                if ctx.num_provided(param) == 0:
+                    yield param
+
     def required_check_params(self) -> Iterator[Parameter]:
         ignore = SubCommand
         yield from (p for p in self.positionals if not isinstance(p, ignore))
