@@ -7,18 +7,19 @@ Parameter usage / help text formatters
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Union, Type, Callable, Tuple, Dict
+from typing import TYPE_CHECKING, Union, Type, Callable, Iterator, Iterable, Tuple, Dict
 
+from ..config import SubcommandAliasHelpMode
 from ..context import ctx
+from ..core import get_config
 from ..parameters.base import BasePositional, BaseOption
-from ..parameters.choice_map import ChoiceMap
-from ..parameters import ParamOrGroup, ParamGroup, PassThru, TriFlag
+from ..parameters.choice_map import ChoiceMap, Choice
+from ..parameters import ParamGroup, PassThru, TriFlag
 from .restructured_text import RstTable
 from .utils import format_help_entry, _should_add_default
 
 if TYPE_CHECKING:
-    from ..utils import Bool
-
+    from ..typing import Bool, ParamOrGroup
 
 BoolFormatterMap = Dict[bool, Callable[[str], str]]
 
@@ -59,16 +60,17 @@ class ParamHelpFormatter:
 
     def format_metavar(self) -> str:
         param = self.param
-        if param.choices:
-            return '{{{}}}'.format(ctx.config.choice_delim.join(map(str, param.choices)))
-        elif param.metavar:
+        if param.metavar:
             return param.metavar
         t = param.type
         if t is not None:
             try:
-                return t.format_metavar(ctx.config.choice_delim)
+                metavar = t.format_metavar(ctx.config.choice_delim)
             except Exception:  # noqa  # pylint: disable=W0703
                 pass
+            else:
+                if metavar is not NotImplemented:
+                    return metavar
 
         if ctx.config.use_type_metavar and t is not None:
             try:
@@ -186,23 +188,99 @@ class ChoiceMapHelpFormatter(ParamHelpFormatter, param_cls=ChoiceMap):
         usage = self.format_usage()
         help_entry = format_help_entry(usage, param.description, 2, tw_offset=tw_offset, prefix=prefix)
 
-        # TODO: Combine choices/aliases that point to the same target sub Command
-        parts = [f'{prefix}{param.title or param._default_title}:', help_entry]
-        for choice in param.choices.values():
-            parts.append(choice.format_help(lpad=4, tw_offset=tw_offset))
-
-        parts.append(prefix.rstrip())
+        parts = (
+            f'{prefix}{param.title or param._default_title}:',
+            help_entry,
+            *self._format_choices(tw_offset),
+            prefix.rstrip(),
+        )
         return '\n'.join(parts)
 
+    def _format_choices(self, tw_offset: int = 0) -> Iterator[str]:
+        mode = ctx.config.cmd_alias_mode or SubcommandAliasHelpMode.ALIAS
+        for choice_group in ChoiceGroup.group_choices(self.param.choices.values()):
+            yield from choice_group.format(mode, tw_offset)
+
     def rst_table(self) -> RstTable:
         param = self.param
         table = RstTable(param.title or param._default_title, param.description)
+        # TODO: Update to work with _format_choices?
         for choice in param.choices.values():
             usage = choice.format_usage()
             table.add_row(f'``{usage}``', choice.help)
         return table
 
 
+class ChoiceGroup:
+    __slots__ = ('choice_strs', 'choices')
+
+    def __init__(self, choice: Choice):
+        choice_str = choice.choice
+        self.choices = [choice]
+        self.choice_strs = [choice_str] if choice_str else []
+
+    @classmethod
+    def group_choices(cls, choices: Iterable[Choice]) -> Iterable[ChoiceGroup]:
+        target_choice_map = {}
+        for n, choice in enumerate(choices):
+            key = (choice.target, n if choice.local else None)
+            try:
+                target_choice_map[key].add(choice)
+            except KeyError:
+                target_choice_map[key] = ChoiceGroup(choice)
+
+        return target_choice_map.values()
+
+    def add(self, choice: Choice):
+        self.choices.append(choice)
+        choice_str = choice.choice
+        if choice_str:
+            self.choice_strs.append(choice_str)
+
+    def format(self, default_mode: SubcommandAliasHelpMode, tw_offset: int = 0) -> Iterator[str]:
+        first = self.choices[0]
+        config = get_config(first.target)  # If it's not a Command, get_config will return None
+        if config:
+            mode = config.cmd_alias_mode or default_mode
+        else:
+            mode = default_mode
+
+        if mode == SubcommandAliasHelpMode.ALIAS:
+            yield from self.format_aliases(tw_offset)
+        elif mode == SubcommandAliasHelpMode.REPEAT:
+            yield from self.format_repeated(tw_offset)
+        else:  # mode == SubcommandAliasHelpMode.COMBINE
+            yield self.format_combined(tw_offset)
+
+    def format_combined(self, tw_offset: int = 0) -> str:
+        first, choice_strs = self.choices[0], self.choice_strs
+        try:
+            usage, *additional = choice_strs
+        except ValueError:  # choice_strs is empty
+            return first.format_help(lpad=4, tw_offset=tw_offset)
+
+        if additional:
+            usage = '{{{}}}'.format('|'.join(choice_strs))
+
+        return first.format_help(lpad=4, tw_offset=tw_offset, usage=usage)
+
+    def format_aliases(self, tw_offset: int = 0) -> Iterator[str]:
+        first = self.choices[0]
+        try:
+            first_str, *choice_strs = self.choice_strs
+        except ValueError:  # choice_strs is empty
+            yield first.format_help(lpad=4, tw_offset=tw_offset)
+        else:
+            yield first.format_help(lpad=4, tw_offset=tw_offset, usage=first_str)
+            description = f'Alias of: {first_str}'
+            for choice_str in choice_strs:
+                yield first.format_help(lpad=4, tw_offset=tw_offset, usage=choice_str, description=description)
+
+    def format_repeated(self, tw_offset: int = 0) -> Iterator[str]:
+        for choice in self.choices:
+            yield choice.format_help(lpad=4, tw_offset=tw_offset)
+
+
 class PassThruHelpFormatter(ParamHelpFormatter, param_cls=PassThru):
     required_formatter_map = {True: '-- {}'.format, False: '[-- {}]'.format}
 
