@@ -8,35 +8,36 @@ from __future__ import annotations
 
 from functools import partial
 from string import whitespace, printable
-from typing import TYPE_CHECKING, Any, Type, Optional, Callable, Union, Collection, Mapping, Dict
+from typing import Type, TypeVar, Generic, Optional, Callable, Union, Collection, Mapping, Dict
 from types import MethodType
 
 from ..context import ctx, ParseState
 from ..exceptions import ParameterDefinitionError, BadArgument, MissingArgument, InvalidChoice, CommandDefinitionError
 from ..formatting.utils import format_help_entry
 from ..nargs import Nargs
+from ..typing import Bool, CommandCls
 from ..utils import _NotSet, camel_to_snake_case
 from .base import BasePositional, parameter_action
 
-if TYPE_CHECKING:
-    from ..core import CommandType
-    from ..typing import Bool
-
 __all__ = ['SubCommand', 'Action']
 
+T = TypeVar('T')
+OptStr = Optional[str]
 
-class Choice:
+
+class Choice(Generic[T]):
     """
     Used internally to store a value that can be provided as a choice for a parameter, and the target value / callable
     associated with that choice.
     """
 
-    __slots__ = ('choice', 'target', 'help')
+    __slots__ = ('choice', 'target', 'help', 'local')
 
-    def __init__(self, choice: Optional[str], target: Any = _NotSet, help: str = None):  # noqa
+    def __init__(self, choice: OptStr, target: T = _NotSet, help: str = None, local: bool = False):  # noqa
         self.choice = choice
         self.target = choice if target is _NotSet else target
         self.help = help
+        self.local = local
 
     def __repr__(self) -> str:
         help_str = f', help={self.help!r}' if self.help else ''
@@ -46,12 +47,15 @@ class Choice:
     def format_usage(self) -> str:
         return '(default)' if self.choice is None else self.choice
 
-    def format_help(self, lpad: int = 4, tw_offset: int = 0, prefix: str = '') -> str:
-        usage = self.format_usage()
-        return format_help_entry(usage, self.help, lpad, tw_offset=tw_offset, prefix=prefix)
+    def format_help(
+        self, lpad: int = 4, tw_offset: int = 0, prefix: str = '', usage: str = None, description: str = None
+    ) -> str:
+        return format_help_entry(
+            usage or self.format_usage(), description or self.help, lpad, tw_offset=tw_offset, prefix=prefix
+        )
 
 
-class ChoiceMap(BasePositional):
+class ChoiceMap(BasePositional[str], Generic[T]):
     """
     Base class for :class:`SubCommand` and :class:`Action`.  It is not meant to be used directly.
 
@@ -73,9 +77,9 @@ class ChoiceMap(BasePositional):
     _choice_validation_exc = ParameterDefinitionError
     _default_title: str = 'Choices'
     nargs = Nargs('+')
-    choices: Dict[str, Choice]
-    title: Optional[str]
-    description: Optional[str]
+    choices: Dict[str, Choice[T]]
+    title: OptStr
+    description: OptStr
 
     def __init_subclass__(  # pylint: disable=W0222
         cls, title: str = None, choice_validation_exc: Type[Exception] = None, **kwargs
@@ -115,15 +119,17 @@ class ChoiceMap(BasePositional):
 
         self.nargs = Nargs(lengths)
 
-    def register_choice(self, choice: str, target: Any = _NotSet, help: str = None):  # noqa
+    def register_choice(self, choice: str, target: T = _NotSet, help: str = None):  # noqa
         _validate_positional(self.__class__.__name__, choice, exc=self._choice_validation_exc)
         self._register_choice(choice, target, help)
 
-    def _register_choice(self, choice: Optional[str], target: Any = _NotSet, help: str = None):  # noqa
+    def _register_choice(
+        self, choice: OptStr, target: Optional[T] = _NotSet, help: str = None, local: bool = False  # noqa
+    ):
         try:
             existing = self.choices[choice]
         except KeyError:
-            self.choices[choice] = Choice(choice, target, help)
+            self.choices[choice] = Choice(choice, target, help, local)
             self._update_nargs()
         else:
             prefix = 'Invalid default' if choice is None else f'Invalid choice={choice!r} for'
@@ -160,7 +166,7 @@ class ChoiceMap(BasePositional):
         elif value.startswith('-'):
             raise BadArgument(self, f'invalid value={value!r}')
 
-    def result_value(self) -> Optional[str]:
+    def result_value(self) -> OptStr:
         choices = self.choices
         if not choices:
             raise CommandDefinitionError(f'No choices were registered for {self}')
@@ -180,7 +186,7 @@ class ChoiceMap(BasePositional):
 
     result = result_value
 
-    def target(self):
+    def target(self) -> T:
         choice = self.result_value()
         return self.choices[choice].target
 
@@ -195,7 +201,7 @@ class ChoiceMap(BasePositional):
     # endregion
 
 
-class SubCommand(ChoiceMap, title='Subcommands', choice_validation_exc=CommandDefinitionError):
+class SubCommand(ChoiceMap[CommandCls], title='Subcommands', choice_validation_exc=CommandDefinitionError):
     """
     Used to indicate the position where a choice that results in delegating execution of the program to a sub-command
     should be provided.
@@ -210,6 +216,7 @@ class SubCommand(ChoiceMap, title='Subcommands', choice_validation_exc=CommandDe
         self,
         *,
         required: Bool = True,
+        default_help: str = None,
         local_choices: Optional[Union[Mapping[str, str], Collection[str]]] = None,
         **kwargs,
     ):
@@ -218,6 +225,7 @@ class SubCommand(ChoiceMap, title='Subcommands', choice_validation_exc=CommandDe
           raised if the user did not provide a value for this parameter.  Defaults to ``True``.  If not required and
           not provided, the :meth:`~.Command.main` method for the base :class:`.Command` that contains this
           SubCommand will be executed by default.
+        :param default_help: Help text to display for the default choice.  Only used if ``required=False``.
         :param local_choices: If some choices should be handled in the Command that this SubCommand is in, they should
           be specified here.  Supports either a mapping of ``{choice: help text}`` or a collection of choice values.
         :param kwargs: Additional keyword arguments to pass to :class:`ChoiceMap`.
@@ -225,7 +233,8 @@ class SubCommand(ChoiceMap, title='Subcommands', choice_validation_exc=CommandDe
         super().__init__(**kwargs)
         self.required = required
         if not required:
-            self._register_choice(None, None)  # Results in next_cmd=None in parse_args, so the base cmd will run
+            # This results in next_cmd=None in parse_args, so the base cmd will run
+            self._register_choice(None, None, default_help)
         if local_choices:
             self._register_local_choices(local_choices)
 
@@ -236,9 +245,9 @@ class SubCommand(ChoiceMap, title='Subcommands', choice_validation_exc=CommandDe
             choice_help_iter = ((choice, None) for choice in local_choices)
 
         for choice, help_text in choice_help_iter:
-            self._register_choice(choice, None, help_text)
+            self._register_choice(choice, None, help_text, True)
 
-    def register_command(self, choice: Optional[str], command: CommandType, help: Optional[str]) -> CommandType:  # noqa
+    def register_command(self, choice: OptStr, command: CommandCls, help: OptStr) -> CommandCls:  # noqa
         if choice is None:
             choice = camel_to_snake_case(command.__name__)
         else:
@@ -257,8 +266,8 @@ class SubCommand(ChoiceMap, title='Subcommands', choice_validation_exc=CommandDe
         return command
 
     def register(
-        self, command_or_choice: Union[str, CommandType] = None, *, choice: str = None, help: str = None  # noqa
-    ) -> Callable[[CommandType], CommandType]:
+        self, command_or_choice: Union[str, CommandCls] = None, *, choice: str = None, help: str = None  # noqa
+    ) -> Callable[[CommandCls], CommandCls]:
         """
         Class decorator version of :meth:`.register_command`.  Registers the wrapped :class:`.Command` as the
         subcommand class to be used for further parsing when the given choice is specified for this parameter.
@@ -286,7 +295,7 @@ class SubCommand(ChoiceMap, title='Subcommands', choice_validation_exc=CommandDe
             return self.register_command(choice, command_or_choice, help=help)  # noqa
 
 
-class Action(ChoiceMap, title='Actions'):
+class Action(ChoiceMap[MethodType], title='Actions'):
     """
     Actions are similar to :class:`.SubCommand` parameters, but allow methods in :class:`.Command` classes to
     be registered as a callable to be executed based on a user's choice instead of separate sub Commands.
@@ -297,7 +306,7 @@ class Action(ChoiceMap, title='Actions'):
     """
 
     def register_action(
-        self, choice: Optional[str], method: MethodType, help: str = None, default: Bool = False  # noqa
+        self, choice: OptStr, method: MethodType, help: str = None, default: Bool = False  # noqa
     ) -> MethodType:
         if help is None:
             try:
